# Using `zampy` in notebooks

It is possible to intereact with `zampy` via Python APIs. Here are some demo notebooks showing how to use `zampy` inside a Jupyter notebook environment for each supported dataset:

 - [ERA5](./era5_dataset_demo.ipynb)
 - [ERA5-land](./era5-land_dataset_demo.ipynb)
 - [ETH canopy height](./eth_dataset_demo.ipynb)
 - [PRISM DEM](./prism_dem_demo.ipynb)
 - [CAMS EGG4](./cams_co2_dataset_demo.ipynb)
 - [Land cover classification gridded maps](./land_cover_dataset_demo.ipynb)
 